.. _index:

DryMass documentation
======================

DryMass is a user-friendly quantitative phase imaging
analysis software.
This is the documentation of DryMass version |release|.

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   sec_introduction
   sec_theory_notes
   sec_getting_started
   sec_tutorials
   sec_examples
   sec_code_reference
   sec_changelog
   z_bib


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
